@@ -359,7 +359,12 @@ class Genius(Backend):
 
         # Gotta go regular html scraping... come on Genius.
         page_url = "https://genius.com" + path
-        page = requests.get(page_url)
+        try:
+            page = requests.get(page_url)
+        except requests.RequestException as exc:
+            self._log.debug(u'Genius page request for {0} failed: {1}',
+                            page_url, exc)
+            return None
         html = BeautifulSoup(page.text, "html.parser")
 
         # Remove script tags that they put in the middle of the lyrics.
@@ -374,8 +379,18 @@ class Genius(Backend):
     def fetch(self, artist, title):
         search_url = self.base_url + "/search"
         data = {'q': title}
-        response = requests.get(search_url, data=data, headers=self.headers)
-        json = response.json()
+        try:
+            response = requests.get(search_url, data=data,
+                                    headers=self.headers)
+        except requests.RequestException as exc:
+            self._log.debug(u'Genius API request failed: {0}', exc)
+            return None
+
+        try:
+            json = response.json()
+        except ValueError:
+            self._log.debug(u'Genius API request returned invalid JSON')
+            return None
 
         song_info = None
         for hit in json["response"]["hits"]:
@@ -659,6 +674,13 @@ class LyricsPlugin(plugins.BeetsPlugin):
                                   u'the documentation for further details.')
                 sources.remove('google')
 
+        if 'genius' in sources and not HAS_BEAUTIFUL_SOUP:
+            self._log.debug(
+                u'The Genius backend requires BeautifulSoup, which is not '
+                u'installed, so the source is disabled.'
+            )
+            sources.remove('genius')
+
         self.config['bing_lang_from'] = [
             x.lower() for x in self.config['bing_lang_from'].as_str_seq()]
         self.bing_auth_token = None
@@ -698,7 +720,7 @@ class LyricsPlugin(plugins.BeetsPlugin):
         )
         cmd.parser.add_option(
             u'-r', u'--write-rest', dest='writerest',
-            action='store', default='.', metavar='dir',
+            action='store', default=None, metavar='dir',
             help=u'write lyrics to given directory as ReST files',
         )
         cmd.parser.add_option(
@@ -750,7 +772,7 @@ class LyricsPlugin(plugins.BeetsPlugin):
         writing continuously to the same files.
         """
 
-        if item is None or slug(self.artist) != slug(item.artist):
+        if item is None or slug(self.artist) != slug(item.albumartist):
             if self.rest is not None:
                 path = os.path.join(directory, 'artists',
                                     slug(self.artist) + u'.rst')
@@ -759,7 +781,7 @@ class LyricsPlugin(plugins.BeetsPlugin):
                 self.rest = None
                 if item is None:
                     return
-            self.artist = item.artist.strip()
+            self.artist = item.albumartist.strip()
             self.rest = u"%s\n%s\n\n.. contents::\n   :local:\n\n" \
                         % (self.artist,
                            u'=' * len(self.artist))
